@@ -5,24 +5,23 @@ from popsynth.auxiliary_sampler import AuxiliarySampler, AuxiliaryParameter
 
 class NormalAuxSampler(AuxiliarySampler):
     _auxiliary_sampler_name = "NormalAuxSampler"
-    
+
     mu = AuxiliaryParameter(default=0)
     tau = AuxiliaryParameter(default=1, vmin=0)
     sigma = AuxiliaryParameter(default=1, vmin=0)
 
     def __init__(self, name: str, observed: bool = True):
-        """FIXME! briefly describe function
+        """
+        A normal distribution sampler
 
-        :param name:
-        :param mu:
-        :param tau:
-        :param sigma:
-        :param observed:
-        :returns:
-        :rtype:
+        :param name: 
+        :type name: str
+        :param observed: 
+        :type observed: bool
+        :returns: 
 
         """
-
+    
         super(NormalAuxSampler, self).__init__(name=name, observed=observed)
 
     def true_sampler(self, size: int):
