@@ -3,6 +3,7 @@ from typing import Any, Dict, List, Optional, Union
 
 import numpy as np
 from class_registry import AutoRegister
+from numpy.typing import ArrayLike
 
 from popsynth.distribution import SpatialContainer
 from popsynth.selection_probability import SelectionProbabilty, UnitySelection
@@ -11,11 +12,8 @@ from popsynth.utils.logging import setup_logger
 from popsynth.utils.meta import Parameter, ParameterMeta
 from popsynth.utils.registry import auxiliary_parameter_registry
 
-#from numpy.typing import ArrayLike
-
 log = setup_logger(__name__)
 
-ArrayLike = List[float]
 SamplerDict = Dict[str, Dict[str, ArrayLike]]
 
 
@@ -23,7 +21,9 @@ class AuxiliaryParameter(Parameter):
     pass
 
 
-class AuxiliarySampler(object, metaclass=AutoRegister(auxiliary_parameter_registry, base_type=ParameterMeta)):
+class AuxiliarySampler(object,
+                       metaclass=AutoRegister(auxiliary_parameter_registry,
+                                              base_type=ParameterMeta)):
     def __init__(self,
                  name: str,
                  observed: bool = True,
@@ -126,7 +126,7 @@ class AuxiliarySampler(object, metaclass=AutoRegister(auxiliary_parameter_regist
 
                 self._selector.set_luminosity(self._luminosity)
 
-            except(AttributeError):
+            except (AttributeError):
 
                 log.debug("tried to set luminosity, but could not")
 
@@ -263,6 +263,52 @@ class AuxiliarySampler(object, metaclass=AutoRegister(auxiliary_parameter_regist
 
         return recursive_secondaries
 
+    def get_secondary_objects(
+        self,
+        recursive_secondaries: Optional[Dict[str, Any]] = None,
+    ) -> Dict[str, Any]:
+        """FIXME! briefly describe function
+
+        :param recursive_secondaries:
+        :returns:
+        :rtype:
+
+        """
+
+        # if a holder was not passed, create one
+        if recursive_secondaries is None:
+
+            recursive_secondaries = {}  # type: SamplerDict
+
+        # now collect each property. This should keep recursing
+        if self._has_secondary:
+
+            for k, v in self._secondary_samplers.items():
+                recursive_secondaries = v.get_secondary_objects(
+                    recursive_secondaries)  # type: SamplerDict
+
+        # add our own on
+
+        tmp = {}
+
+        tmp["type"] = self._auxiliary_sampler_name
+        tmp["observed"] = self.observed
+
+        for k2, v2 in self.truth.items():
+
+            tmp[k2] = v2
+
+        tmp["secondary"] = list(self.secondary_samplers.keys())
+
+        selection = {}
+        selection[self.selector._selection_name] = self.selector.parameters
+
+        tmp["selection"] = selection
+
+        recursive_secondaries[self._name] = tmp
+
+        return recursive_secondaries
+
     @property
     def secondary_samplers(self) -> SamplerDict:
         """
