@@ -4,6 +4,7 @@ from typing import Dict, List, Union
 
 import numpy as np
 from class_registry import AutoRegister
+from numpy.typing import ArrayLike
 
 from popsynth.utils.configuration import popsynth_config
 from popsynth.utils.logging import setup_logger
@@ -13,10 +14,6 @@ from popsynth.utils.registry import distribution_registry
 from popsynth.utils.rejection_sample import rejection_sample
 from popsynth.utils.spherical_geometry import sample_theta_phi
 
-#from numpy.typing import ArrayLike
-
-ArrayLike = List[float]
-
 log = setup_logger(__name__)
 
 
@@ -24,7 +21,9 @@ class DistributionParameter(Parameter):
     pass
 
 
-class Distribution(object, metaclass=AutoRegister(distribution_registry, base_type=ParameterMeta)):
+class Distribution(object,
+                   metaclass=AutoRegister(distribution_registry,
+                                          base_type=ParameterMeta)):
     _distribution_name = "Distribution"
 
     def __init__(self, name: str, seed: int, form: str) -> None:
@@ -131,7 +130,8 @@ class SpatialDistribution(Distribution):
         pass
 
     def time_adjustment(self, r):
-        """FIXME! briefly describe function
+        """
+        the time adjustment
 
         :param r:
         :returns:
