@@ -8,6 +8,7 @@ from popsynth.utils.cosmology import cosmology
 
 class CosmologicalDistribution(SpatialDistribution):
     _distribution_name = "CosmologicalDistribution"
+
     def __init__(self,
                  seed=1234,
                  name="cosmo",
@@ -15,6 +16,22 @@ class CosmologicalDistribution(SpatialDistribution):
                  truth={},
                  is_rate=True):
 
+        """
+        base cosmological spatial distribution
+
+        :param seed: 
+        :type seed: 
+        :param name: 
+        :type name: 
+        :param form: 
+        :type form: 
+        :param truth: 
+        :type truth: 
+        :param is_rate: 
+        :type is_rate: 
+        :returns: 
+
+        """
         super(CosmologicalDistribution, self).__init__(
             seed=seed,
             name=name,
@@ -41,12 +58,26 @@ class SFRDistribution(CosmologicalDistribution):
     _distribution_name = "SFRDistribution"
 
     r0 = DistributionParameter(vmin=0)
+    a = DistributionParameter(vmin=0)
     rise = DistributionParameter()
     decay = DistributionParameter()
     peak = DistributionParameter(vmin=0)
 
     def __init__(self, seed=1234, name="sfr", is_rate=True):
 
+        """
+        A star-formation like distribution of the form
+        presented in Cole et al. 2001
+
+        :param seed: 
+        :type seed: 
+        :param name: 
+        :type name: 
+        :param is_rate: 
+        :type is_rate: 
+        :returns: 
+
+        """
         spatial_form = r"\rho_0 \frac{1+r \cdot z}{1+ \left(z/p\right)^d}"
 
         super(SFRDistribution, self).__init__(
@@ -60,6 +91,7 @@ class SFRDistribution(CosmologicalDistribution):
         return _dndv(
             z,
             self.r0,
+            self.a,
             self.rise,
             self.decay,
             self.peak,
@@ -67,8 +99,8 @@ class SFRDistribution(CosmologicalDistribution):
 
 
 @nb.njit(fastmath=True)
-def _dndv(z, r0, rise, decay, peak):
-    top = 1.0 + rise * z
+def _dndv(z, r0, a, rise, decay, peak):
+    top = a + rise * z
     bottom = 1.0 + np.power(z / peak, decay)
 
     return r0 * top / bottom
@@ -87,6 +119,19 @@ class ZPowerCosmoDistribution(CosmologicalDistribution):
         is_rate=True,
     ):
 
+        """
+        a cosmological distribution where the density 
+        evolves as a power law
+
+        :param seed: 
+        :type seed: 
+        :param name: 
+        :type name: 
+        :param is_rate: 
+        :type is_rate: 
+        :returns: 
+
+        """
         spatial_form = r"\Lambda (z+1)^{\delta}"
 
         super(ZPowerCosmoDistribution, self).__init__(
@@ -100,12 +145,12 @@ class ZPowerCosmoDistribution(CosmologicalDistribution):
 
         return _zp_dndv(distance, self.Lambda, self.delta)
 
+
 @nb.njit(fastmath=True)
 def _zp_dndv(z, Lambda, delta):
     return Lambda * np.power(z + 1, delta)
-    
 
-    
+
 # class MergerDistribution(CosmologicalDistribution):
 #_distribution_name = "MergerDistribution"
 #     def __init__(self, r0, td, sigma, r_max=10, seed=1234, name="merger"):
