@@ -11,6 +11,7 @@ import pandas as pd
 import pythreejs
 from betagen import betagen
 from IPython.display import Markdown, Math, display
+from numpy.typing import ArrayLike
 
 from popsynth.utils.array_to_cmap import array_to_cmap
 from popsynth.utils.hdf5_utils import (
@@ -22,46 +23,39 @@ from popsynth.utils.spherical_geometry import xyz
 
 log = setup_logger(__name__)
 
-# from numpy.typing import ArrayLike
-
-# dummy
-ArrayLike = List[float]
-
 wine = "#8F2727"
 dark, dark_highlight, mid, mid_highlight, light, light_highlight = betagen(
     wine)
 
 
 class Population(object):
-    def __init__(
-        self,
-        luminosities: ArrayLike,
-        distances: ArrayLike,
-        known_distances: ArrayLike,
-        known_distance_idx: ArrayLike,
-        unknown_distance_idx: ArrayLike,
-        fluxes: ArrayLike,
-        flux_obs: ArrayLike,
-        selection: ArrayLike,
-        flux_sigma: float,
-        r_max: float,
-        n_model: int,
-        lf_params: Dict[str, Any],
-        spatial_params: Optional[Dict[str, Any]] = None,
-        model_spaces: Optional[ArrayLike] = None,
-        seed: int = 1234,
-        name: Optional[str] = None,
-        spatial_form: Optional[Dict[str, Any]] = None,
-        lf_form: Optional[Dict[str, Any]] = None,
-        auxiliary_quantities: Optional[Dict[str, Any]] = None,
-        truth: Dict[str, float] = {},
-        graph: Optional[Dict[str, Any]] = None,
-        theta=None,
-        phi=None,
-        pop_synth: Optional[Dict[str, Any]] = None
-    ) -> None:
+    def __init__(self,
+                 luminosities: ArrayLike,
+                 distances: ArrayLike,
+                 known_distances: ArrayLike,
+                 known_distance_idx: ArrayLike,
+                 unknown_distance_idx: ArrayLike,
+                 fluxes: ArrayLike,
+                 flux_obs: ArrayLike,
+                 selection: ArrayLike,
+                 flux_sigma: float,
+                 r_max: float,
+                 n_model: int,
+                 lf_params: Dict[str, Any],
+                 spatial_params: Optional[Dict[str, Any]] = None,
+                 model_spaces: Optional[ArrayLike] = None,
+                 seed: int = 1234,
+                 name: Optional[str] = None,
+                 spatial_form: Optional[Dict[str, Any]] = None,
+                 lf_form: Optional[Dict[str, Any]] = None,
+                 auxiliary_quantities: Optional[Dict[str, Any]] = None,
+                 truth: Dict[str, float] = {},
+                 graph: Optional[Dict[str, Any]] = None,
+                 theta=None,
+                 phi=None,
+                 pop_synth: Optional[Dict[str, Any]] = None) -> None:
         """
-        A population containing all the simulated variables
+        A population container for all the properties of the population.
 
         :param luminosities: the luminosities
         :param distances: the distances
@@ -189,23 +183,53 @@ class Population(object):
 
     @property
     def flux_sigma(self) -> float:
+        """
+        the simulated flux sigma
 
+        :returns: 
+
+        """
+        
         return self._flux_sigma
 
     @property
     def theta(self) -> np.ndarray:
+        """
+        the polar angle of the objects
+
+        :returns: 
+
+        """
         return self._theta
 
     @property
     def phi(self) -> np.ndarray:
+        """
+        the phi angle of the objects
+
+        :returns: 
+
+        """
         return self._phi
 
     @property
     def dec(self) -> np.ndarray:
+        """
+        the declenation of the objects
+
+        :returns: 
+
+        """
         return 90 - np.rad2deg(self._theta)
 
     @property
     def ra(self) -> np.ndarray:
+        """
+        the right ascension of the objects
+
+        :returns: 
+
+        """
         return np.rad2deg(self._phi)
 
     @property
@@ -349,6 +373,15 @@ class Population(object):
     def spatial_parameters(self):
         return self._spatial_params
 
+    def __repr__(self):
+
+        out = ""
+        out += f"total number of objects: {self.n_detections + self.n_non_detections}"
+        out += f"\n number of detections: {self.n_detections}"
+        out += f"\n number of non-detections: {self.n_non_detections}"
+
+        return out
+
     def to_stan_data(self) -> dict:
         """
         Create Stan input
@@ -619,32 +652,30 @@ class Population(object):
 
         pop_synth = recursively_load_dict_contents_from_group(f, "popsynth")
 
-        return cls(
-            luminosities=luminosities,
-            distances=distances,
-            known_distances=known_distances,
-            known_distance_idx=known_distance_idx,
-            unknown_distance_idx=unknown_distance_idx,
-            fluxes=fluxes,
-            flux_obs=flux_obs,
-            selection=selection,
-            flux_sigma=flux_sigma,
-            n_model=n_model,
-            r_max=r_max,
-            lf_params=lf_params,
-            spatial_params=spatial_params,
-            model_spaces=model_spaces,
-            seed=seed,
-            name=name,
-            spatial_form=spatial_form,
-            lf_form=lf_form,
-            auxiliary_quantities=auxiliary_quantities,
-            truth=truth,
-            graph=graph,
-            theta=theta,
-            phi=phi,
-            pop_synth=pop_synth
-        )
+        return cls(luminosities=luminosities,
+                   distances=distances,
+                   known_distances=known_distances,
+                   known_distance_idx=known_distance_idx,
+                   unknown_distance_idx=unknown_distance_idx,
+                   fluxes=fluxes,
+                   flux_obs=flux_obs,
+                   selection=selection,
+                   flux_sigma=flux_sigma,
+                   n_model=n_model,
+                   r_max=r_max,
+                   lf_params=lf_params,
+                   spatial_params=spatial_params,
+                   model_spaces=model_spaces,
+                   seed=seed,
+                   name=name,
+                   spatial_form=spatial_form,
+                   lf_form=lf_form,
+                   auxiliary_quantities=auxiliary_quantities,
+                   truth=truth,
+                   graph=graph,
+                   theta=theta,
+                   phi=phi,
+                   pop_synth=pop_synth)
 
     def to_sub_population(self, observed: bool = True) -> "Population":
         """
@@ -788,7 +819,7 @@ class Population(object):
             **kwargs,
         )
 
-#        ax.axhline(self._boundary, color="grey", zorder=-5000, ls="--")
+        #        ax.axhline(self._boundary, color="grey", zorder=-5000, ls="--")
 
         # ax.set_xscale('log')
         ax.set_yscale("log")
@@ -807,7 +838,8 @@ class Population(object):
         ax.set_ylabel("flux")
 
     def display_obs_fluxes(self, ax=None, flux_color=dark, **kwargs):
-        """FIXME! briefly describe function
+        """
+        display the observed fluxes
 
         :param ax:
         :param flux_color:
@@ -847,7 +879,7 @@ class Population(object):
             **kwargs,
         )
 
-#        ax.axhline(self._boundary, color="grey", zorder=-5000, ls="--")
+        #        ax.axhline(self._boundary, color="grey", zorder=-5000, ls="--")
         # ax.set_xscale('log')
         ax.set_yscale("log")
 
@@ -868,7 +900,8 @@ class Population(object):
         with_arrows=True,
         **kwargs,
     ):
-        """FIXME! briefly describe function
+        """
+        display the fluxes
 
         :param ax:
         :param true_color:
@@ -924,7 +957,8 @@ class Population(object):
         obs_color=dark,
         **kwargs,
     ):
-        """FIXME! briefly describe function
+        """
+        display the luminosities
 
         :param ax:
         :param true_color:
@@ -1106,37 +1140,9 @@ class Population(object):
 
         return fig
 
-    # def display_luminosty(self, ax=None, **kwargs):
-
-    #     if self._no_detection:
-    #         return
-
-    #     if ax is None:
-    #         fig, ax = plt.subplots()
-
-    #     else:
-
-    #         fig = ax.get_figure()
-
-    #     bins = np.logspace(
-    #         np.log10(self._luminosities.min()), np.log10(self._luminosities.max()), 30
-    #     )
-
-    #     ax.hist(
-    #         self._luminosities,
-    #         #bins=bins,
-    #         #density=True,
-    #         fc=dark,
-    #         ec=dark_highlight,
-    #         lw=1.5,
-    #     )
-
-    #     ax.set_xscale("log")
-    #     ax.set_yscale("log")
-    #     ax.set_xlabel("L")
-
     def display_distances(self, ax=None):
-        """FIXME! briefly describe function
+        """
+        display the distances
 
         :param ax:
         :returns:
