@@ -6,24 +6,26 @@ import networkx as nx
 import numpy as np
 import pandas as pd
 import scipy.integrate as integrate
-import scipy.special as sf
-import scipy.stats as stats
+
 import yaml
 from IPython.display import Markdown, Math, display
+
 # from numpy.typing import np.ndarray
-from numba import float64, jit, njit, prange
+
 
 from popsynth.auxiliary_sampler import AuxiliarySampler, DerivedLumAuxSampler
 from popsynth.distribution import LuminosityDistribution, SpatialDistribution
+from popsynth.distributions.cosmological_distribution import CosmologicalDistribution
 from popsynth.population import Population
-from popsynth.selection_probability import (BernoulliSelection,
-                                            HardFluxSelection,
-                                            SelectionProbabilty,
-                                            SoftFluxSelection, UnitySelection)
+from popsynth.selection_probability import ( SelectionProbabilty,
+                                             UnitySelection)
 from popsynth.utils.logging import setup_logger
 from popsynth.utils.progress_bar import progress_bar
-from popsynth.utils.registry import (auxiliary_parameter_registry,
-                                     distribution_registry, selection_registry)
+from popsynth.utils.registry import (
+    auxiliary_parameter_registry,
+    distribution_registry,
+    selection_registry,
+)
 
 log = setup_logger(__name__)
 
@@ -39,9 +41,9 @@ class PopulationSynth(object, metaclass=ABCMeta):
         Basic and generic population synth. One specifies the spatial and luminosity distribution OR
         derived luminosity distribution and everything is setup.
 
-        :param spatial_distribution:
-        :param luminosity_distribution:
-        :param seed:
+        :param spatial_distribution: The spatial distribution to sample locations from
+        :param luminosity_distribution: the optional luminosity distribution
+        :param seed: random see
         :returns:
         :rtype:
 
@@ -58,25 +60,23 @@ class PopulationSynth(object, metaclass=ABCMeta):
 
         self._graph = nx.DiGraph()  # type: nx.Digraph
 
-        self._name = f"{spatial_distribution.name}"  # type: str
-        if luminosity_distribution is not None:
-            self._name = f"{self._name}_{luminosity_distribution.name}"
+        if not isinstance(spatial_distribution, SpatialDistribution):
 
-            if not isinstance(
-                luminosity_distribution, LuminosityDistribution
-            ):
+            log.error("the spatial_distribution is the wrong type")
+
+            raise RuntimeError()
+
+        self._name = f"{spatial_distribution.name}"  # type: str
+
+        if luminosity_distribution is not None:
+
+            if not isinstance(luminosity_distribution, LuminosityDistribution):
 
                 log.error("the luminosity_distribution is the wrong type")
 
                 raise RuntimeError()
 
-        if not isinstance(
-                spatial_distribution,
-                SpatialDistribution):
-
-            log.error("the spatial_distribution is the wrong type")
-
-            raise RuntimeError()
+            self._name = f"{self._name}_{luminosity_distribution.name}"
 
         self._spatial_distribution = spatial_distribution  # type: SpatialDistribution
         self._luminosity_distribution = (
@@ -117,7 +117,7 @@ class PopulationSynth(object, metaclass=ABCMeta):
 
     def clean(self, reset: bool = False):
         """
-        clean the auxiliary samplers, selections, etc 
+        clean the auxiliary samplers, selections, etc
         from the population synth
         :param reset: reset any attached distributions and samplers
 
@@ -182,8 +182,12 @@ class PopulationSynth(object, metaclass=ABCMeta):
         """
         with open(file_name, "w") as f:
 
-            yaml.dump(stream=f, data=self.to_dict(),
-                      default_flow_style=False, Dumper=yaml.SafeDumper)
+            yaml.dump(
+                stream=f,
+                data=self.to_dict(),
+                default_flow_style=False,
+                Dumper=yaml.SafeDumper,
+            )
 
     def to_dict(self) -> Dict[str, Any]:
         """
@@ -198,7 +202,16 @@ class PopulationSynth(object, metaclass=ABCMeta):
 
         spatial_distribution = {}
 
-        spatial_distribution[self._spatial_distribution._distribution_name] = self._spatial_distribution.truth
+        spatial_distribution[
+            self._spatial_distribution.
+            _distribution_name] = self._spatial_distribution.truth
+
+        # store is_rate if cosmological distribution
+
+        if isinstance(self._spatial_distribution, CosmologicalDistribution):
+
+            spatial_distribution[
+                "is_rate"] = self._spatial_distribution._is_rate
 
         output["spatial distribution"] = spatial_distribution
 
@@ -209,7 +222,9 @@ class PopulationSynth(object, metaclass=ABCMeta):
 
             luminosity_distribution = {}
 
-            luminosity_distribution[self._luminosity_distribution._distribution_name] = self._luminosity_distribution.truth
+            luminosity_distribution[
+                self._luminosity_distribution.
+                _distribution_name] = self._luminosity_distribution.truth
 
             output["luminosity distribution"] = luminosity_distribution
 
@@ -217,7 +232,8 @@ class PopulationSynth(object, metaclass=ABCMeta):
 
             flux_selection = {}
 
-            flux_selection[self._flux_selector._selection_name] = self._flux_selector.parameters
+            flux_selection[self._flux_selector.
+                           _selection_name] = self._flux_selector.parameters
 
             output["flux selection"] = flux_selection
 
@@ -225,7 +241,9 @@ class PopulationSynth(object, metaclass=ABCMeta):
 
             distance_selection = {}
 
-            distance_selection[self._distance_selector._selection_name] = self._distance_selector.parameters
+            distance_selection[
+                self._distance_selector.
+                _selection_name] = self._distance_selector.parameters
 
             output["distance selection"] = distance_selection
 
@@ -233,7 +251,9 @@ class PopulationSynth(object, metaclass=ABCMeta):
 
             spatial_selection = {}
 
-            spatial_selection[self._spatial_selector._selection_name] = self._spatial_selector.parameters
+            spatial_selection[
+                self._spatial_selector.
+                _selection_name] = self._spatial_selector.parameters
 
             output["spatial selection"] = spatial_selection
 
@@ -243,7 +263,7 @@ class PopulationSynth(object, metaclass=ABCMeta):
 
             tmp = {}
 
-            tmp["name"] = v.name
+            tmp["type"] = v._auxiliary_sampler_name
             tmp["observed"] = v.observed
 
             for k2, v2 in v.truth.items():
@@ -257,7 +277,11 @@ class PopulationSynth(object, metaclass=ABCMeta):
 
             tmp["selection"] = selection
 
-            aux_samplers[v._auxiliary_sampler_name] = tmp
+            aux_samplers[k] = tmp
+
+            if v.has_secondary:
+
+                aux_samplers = v.get_secondary_objects(aux_samplers)
 
         output["auxiliary samplers"] = aux_samplers
 
@@ -283,7 +307,8 @@ class PopulationSynth(object, metaclass=ABCMeta):
 
             # create the instance
 
-            luminosity_distribtuion: LuminosityDistribution = distribution_registry[ld_name]
+            luminosity_distribtuion: LuminosityDistribution = distribution_registry[
+                ld_name]
 
             # now set the values of the parameters
 
@@ -313,26 +338,34 @@ class PopulationSynth(object, metaclass=ABCMeta):
 
         sd_name = list(tmp.keys())[0]
 
-        spatial_distribtuion: SpatialDistribution = distribution_registry[sd_name]
+        spatial_distribution: SpatialDistribution = distribution_registry[
+            sd_name]
 
         for k, v in tmp[sd_name].items():
 
             log.debug(f"trying to set {k} to {v}")
 
-            for x in spatial_distribtuion.__class__.mro():
+            for x in spatial_distribution.__class__.mro():
 
                 if k in x.__dict__:
 
-                    setattr(spatial_distribtuion, k, float(v))
+                    setattr(spatial_distribution, k, float(v))
 
                     break
 
+        if isinstance(spatial_distribution, CosmologicalDistribution):
+
+            spatial_distribution._is_rate = tmp["is_rate"]
+
         seed: int = input["seed"]
 
         # create the poopulation synth
 
         pop_synth: PopulationSynth = cls(
-            spatial_distribtuion, luminosity_distribution=luminosity_distribtuion, seed=seed)
+            spatial_distribution,
+            luminosity_distribution=luminosity_distribtuion,
+            seed=seed,
+        )
 
         # if there is a flux selection
         # then add it on
@@ -373,7 +406,7 @@ class PopulationSynth(object, metaclass=ABCMeta):
 
                 # oh yes we are doing that
                 fs._use_flux = True
-                
+
                 pop_synth.set_flux_selection(fs)
 
         if "distance selection" in input:
@@ -413,7 +446,7 @@ class PopulationSynth(object, metaclass=ABCMeta):
                             break
 
                 ds._use_distance = True
-                        
+
                 pop_synth.set_distance_selection(ds)
 
         if "spatial selection" in input:
@@ -462,17 +495,19 @@ class PopulationSynth(object, metaclass=ABCMeta):
 
         if "auxiliary samplers" in input:
 
-            for k, v in input["auxiliary samplers"].items():
+            for obj_name, v in input["auxiliary samplers"].items():
 
                 # first we extract the required info
 
-                sampler_name = k
-                obj_name = v.pop("name")
+                sampler_name = v.pop("type")
                 is_observed = v.pop("observed")
 
                 # now we extract the selection
                 # and secondary if they are there
 
+                log.debug(
+                    f"starting to scan {obj_name} of type {sampler_name}")
+
                 if "selection" in v:
                     selection = v.pop("selection")
 
@@ -481,7 +516,19 @@ class PopulationSynth(object, metaclass=ABCMeta):
                     selection = None
 
                 if "secondary" in v:
-                    secondary = list(np.atleast_1d(v.pop("secondary")))
+
+                    log.debug(f"auxiliary sampler {obj_name} has secondaries")
+
+                    secondary = v.pop("secondary")
+
+                    if isinstance(secondary, dict):
+
+                        secondary = list(np.atleast_1d(list(secondary.keys())))
+
+                    else:
+                        secondary = list(np.atleast_1d(secondary))
+
+                    log.debug(f"secondaries are {secondary}")
 
                 else:
 
@@ -511,10 +558,10 @@ class PopulationSynth(object, metaclass=ABCMeta):
                         sampler_name,
                         name=obj_name,
                         observed=is_observed,
+                        **init_variables,
+                    )
 
-                        **init_variables)
-
-                except(TypeError):
+                except (TypeError):
 
                     # try without name
 
@@ -524,10 +571,10 @@ class PopulationSynth(object, metaclass=ABCMeta):
                             sampler_name,
                             # name=obj_name,
                             observed=is_observed,
+                            **init_variables,
+                        )
 
-                            **init_variables)
-
-                    except(TypeError):
+                    except (TypeError):
 
                         try:
 
@@ -535,10 +582,10 @@ class PopulationSynth(object, metaclass=ABCMeta):
                                 sampler_name,
                                 name=obj_name,
                                 # observed=is_observed,
+                                **init_variables,
+                            )
 
-                                **init_variables)
-
-                        except(TypeError):
+                        except (TypeError):
 
                             tmp: AuxiliarySampler = auxiliary_parameter_registry.get(
                                 sampler_name, **init_variables)
@@ -592,7 +639,7 @@ class PopulationSynth(object, metaclass=ABCMeta):
                             setattr(selector, k, float(v))
 
                     selector._use_obs_value = True
-                    
+
                     tmp.set_selection_probability(selector)
 
                 # now we store this sampler
@@ -606,6 +653,9 @@ class PopulationSynth(object, metaclass=ABCMeta):
 
                 if secondary is not None:
 
+                    log.debug(
+                        f"{obj_name} is adding {secondary} as secondaries")
+
                     secondary_samplers[obj_name] = secondary
 
         # Now we have collected all of the auxiliary samplers
@@ -714,16 +764,18 @@ class PopulationSynth(object, metaclass=ABCMeta):
         if isinstance(auxiliary_sampler, DerivedLumAuxSampler):
 
             log.info(
-                f"registering derived luminosity sampler: {auxiliary_sampler.name}")
+                f"registering derived luminosity sampler: {auxiliary_sampler.name}"
+            )
 
             self._has_derived_luminosity = True
             self._derived_luminosity_sampler = auxiliary_sampler
 
-        else:
+        elif isinstance(auxiliary_sampler, AuxiliarySampler):
 
             if auxiliary_sampler.is_secondary:
                 log.error(
-                    f"{auxiliary_sampler.name} is already set as a secondary sampler!")
+                    f"{auxiliary_sampler.name} is already set as a secondary sampler!"
+                )
                 log.error(
                     f"and registered to {','.join(auxiliary_sampler.parents)}")
 
@@ -741,6 +793,12 @@ class PopulationSynth(object, metaclass=ABCMeta):
             self._auxiliary_observations[
                 auxiliary_sampler.name] = auxiliary_sampler
 
+        else:
+
+            log.error("This not an auxiliary sampler")
+
+            raise RuntimeError()
+
     def set_distance_selection(self, selector: SelectionProbabilty) -> None:
         """
         Set the selection type for the distance
@@ -819,8 +877,16 @@ class PopulationSynth(object, metaclass=ABCMeta):
         log10_flux_draw: bool = True,
     ) -> Population:
         """
-        Draw the total survey and return a Population object
+        Draw the total survey and return a Population object.
+        
+        This will sample all attached distributions and apply selection functions.
+        
+        If a value of flux_sigma is given, the log10 observed fluxes are sampled with 
+        measurement error.
+        
+
         :param flux_sigma: the homoskedastic sigma for the flux in log10 space
+        :param log10_flux_draw: if True, fluxes are drawn in log space
         :return: a Population object
         """
 
@@ -838,7 +904,7 @@ class PopulationSynth(object, metaclass=ABCMeta):
         # create a callback of the integrand
         dNdr = (lambda r: self._spatial_distribution.dNdV(
             r) * self._spatial_distribution.differential_volume(r) / self.
-            _spatial_distribution.time_adjustment(r))
+                _spatial_distribution.time_adjustment(r))
 
         # integrate the population to determine the true number of
         # objects
@@ -1034,16 +1100,16 @@ class PopulationSynth(object, metaclass=ABCMeta):
 
                     log.debug("making a log10 flux draw")
 
-                    log10_fluxes_obs = self.draw_log10_fobs(fluxes, flux_sigma,
-                                                            size=n)  # type: np.ndarray
+                    log10_fluxes_obs = self.draw_log10_fobs(
+                        fluxes, flux_sigma, size=n)  # type: np.ndarray
                     flux_obs = np.power(10, log10_fluxes_obs)
 
                 else:
 
                     log.debug("making a logflux draw")
 
-                    log10_fluxes_obs = self.draw_log_fobs(fluxes, flux_sigma,
-                                                          size=n)  # type: np.ndarray
+                    log10_fluxes_obs = self.draw_log_fobs(
+                        fluxes, flux_sigma, size=n)  # type: np.ndarray
 
                     flux_obs = np.exp(log10_fluxes_obs)
 
@@ -1078,6 +1144,14 @@ class PopulationSynth(object, metaclass=ABCMeta):
 
         for k, v in auxiliary_quantities.items():
 
+            # unity selections don't add anything
+
+            if isinstance(v["selection"], UnitySelection):
+
+                log.debug(f"skipping {k} selection because it is unity")
+
+                continue
+
             auxiliary_selection += v["selection"]
 
             log.info(
@@ -1099,7 +1173,7 @@ class PopulationSynth(object, metaclass=ABCMeta):
 
         # now scan the spatial selector
 
-        if (self._spatial_selector is not None):
+        if self._spatial_selector is not None:
 
             self._spatial_selector.set_spatial_distribution(
                 self._spatial_distribution)
@@ -1128,7 +1202,8 @@ class PopulationSynth(object, metaclass=ABCMeta):
         try:
 
             log.info(
-                f"Detected {global_selection.n_selected} objects out to a distance of {max(known_distances):.2f}")
+                f"Detected {global_selection.n_selected} objects out to a distance of {max(known_distances):.2f}"
+            )
 
         except:
 
@@ -1169,7 +1244,7 @@ class PopulationSynth(object, metaclass=ABCMeta):
             graph=self.graph,
             theta=self._spatial_distribution.theta,
             phi=self._spatial_distribution.phi,
-            pop_synth=self.to_dict()
+            pop_synth=self.to_dict(),
         )
 
     def display(self) -> None:
