@@ -15,8 +15,15 @@ class SelectionParameter(Parameter):
     pass
 
 
-class SelectionProbabilty(object, metaclass=AutoRegister(selection_registry, base_type=ParameterMeta)):
-    def __init__(self, name: str = "name", use_obs_value: bool = False, use_distance: bool = False, use_luminosity: bool = False, use_flux: bool = False) -> None:
+class SelectionProbabilty(object,
+                          metaclass=AutoRegister(selection_registry,
+                                                 base_type=ParameterMeta)):
+    def __init__(self,
+                 name: str = "name",
+                 use_obs_value: bool = False,
+                 use_distance: bool = False,
+                 use_luminosity: bool = False,
+                 use_flux: bool = False) -> None:
 
         self._name = name  # type: str
 
@@ -49,7 +56,8 @@ class SelectionProbabilty(object, metaclass=AutoRegister(selection_registry, bas
     #     return self.__add__(other)
 
     def set_luminosity(self, luminosity: np.ndarray) -> None:
-        """FIXME! briefly describe function
+        """
+        set the luminosity of the selection
 
         :param luminosity:
         :returns:
@@ -60,7 +68,8 @@ class SelectionProbabilty(object, metaclass=AutoRegister(selection_registry, bas
         self._luminosity = luminosity  # type: np.ndarray
 
     def set_distance(self, distance: np.ndarray) -> None:
-        """FIXME! briefly describe function
+        """
+        set the distance of the selection
 
         :param distance:
         :returns:
@@ -71,7 +80,8 @@ class SelectionProbabilty(object, metaclass=AutoRegister(selection_registry, bas
         self._distance = distance  # type: np.ndarray
 
     def set_observed_flux(self, observed_flux: np.ndarray) -> None:
-        """FIXME! briefly describe function
+        """
+        set the observed flux of the selection
 
         :param luminosity:
         :returns:
